
--[[

	Options window related functions

]]--

g_BBarO = {};
g_BBarO.WindowLock = 0;		-- Is the main bar locked or movable
g_BBarO.ShowHintTT = 1;		-- Bar button tooltips
g_BBarO.ShowInfoTT = 1;		-- Bar info tooltips
g_BBarO.MinOnCombat = 0;	-- Minimise the bar on combat
g_BBarO.MinOnInst = 0;		-- Minimise when entering instance
g_BBarO.BarGrowDir = 0;		-- Rep bars browing direction 1 = up, 0 = down


g_BBarO.SliderValues = {18, 1, 18, 1};			-- Rep height, rep alpha, prof height, prof alpha
g_BBarO.SliderOldValues = {0, 0, 0, 0};		-- Store old values to prevent spam.
g_BBarO.MinimiseState = {0, 0};		-- Minimise type and state


function BBar_ToggleMoving(self)

	local state = g_BBarO.WindowLock;	-- if self is nil, use g_BBarO.WindowLock.
	if(self) then state = self:GetChecked(); end
	g_BBar.BBarTitleRegion:ClearAllPoints();
	if(state and (state == 1)) then
		g_BBar.BBarTitleRegion:SetPoint("TOP", UIParent, 0, math.huge);	-- Disable Moving
		g_BBarO.WindowLock = 1;
	else
		g_BBar.BBarTitleRegion:SetAllPoints();	-- Enable moving
		g_BBarO.WindowLock = 0;
	end
	BBar_SaveLoadSettingsOptions(1);
end

-- Accessor functions for XML
function BBar_GetHintTT()			return g_BBarO.ShowHintTT;	end
function BBar_GetInfoTT()			return g_BBarO.ShowInfoTT;	end

-- Toggle callback functions for checkboxes
function BBar_ToggleHintTT(self)	g_BBarO.ShowHintTT = _C(self:GetChecked(), 1, 0);	BBar_SaveLoadSettingsOptions(1);	end
function BBar_ToggleInfoTT(self)	g_BBarO.ShowInfoTT = _C(self:GetChecked(), 1, 0);	BBar_SaveLoadSettingsOptions(1);	end
function BBar_ToggleMinOnC(self)	g_BBarO.MinOnCombat = _C(self:GetChecked(), 1, 0);	BBar_SaveLoadSettingsOptions(1);	end
function BBar_ToggleMinOnI(self)	g_BBarO.MinOnInst = _C(self:GetChecked(), 1, 0);	BBar_SaveLoadSettingsOptions(1);	end
function BBar_ToggleBarDir(self)	g_BBarO.BarGrowDir = _C(self:GetChecked(), 1, 0);	BBar_SaveLoadSettingsOptions(1);	BBar_UpdateBar();	end


function BBar_SliderValChanged(self, value, id)

	if(g_BBarO.SliderOldValues[id] ~= value) then
		g_BBarO.SliderOldValues[id] = value;
		g_BBarO.SliderValues[id] = value;
		if(_G[self:GetName() .. 'Txt'])	then _G[self:GetName() .. 'Txt']:SetText(tostring(value)) end;
		BBar_SaveLoadSettingsOptions(1);
		BBar_UpdateBar();
	end
end


function BBar_ResetEverything()

	-- Remove all the bars first
	for pos, values in pairs(g_BBar.BBarObjectsReps_Faction) do		BBar_AddNewReputationBar(0, 0, values[1], 0, 0);	end
	for i = 1, 6, 1 do	BBar_AddNewProfessionBar(0, 0, i, 0, 0, 0, 0, 0);	end
	for i = 1, getn(g_BBar.BBarObjectsItems), 1 do	BBar_AddNewCurrencyToken(0, 0, -g_BBar.BBarObjectsItems[i], 0);	end

	BBar_SetDefaults();		-- Clear all values

	ValuesToString();
	BBar_SaveLoadSettingsOptions(1);
	BBar_UpdateSettings();
	BBar_UpdateBar();
end


----------------------------------------------
-- Options


function BBar_CreateOptionsCheck(parent, text, id, pos, ClickFunc)

	local item = _G["BBarSettingsOptionItem"..id];
	if( not item ) then
		item = CreateFrame("CheckButton", "BBarSettingsOptionItem"..id, parent, "UICheckButtonTemplate");
		item:SetSize(22, 22);
	else	item:ClearAllPoints();
	end
	local textObj = _G[item:GetName().."Text"];
	textObj:SetText(text);
	textObj:SetFontObject(GameFontNormalLeft);
	textObj:SetTextColor(1, 1, 1, 1);
	local point, relativeTo, relativePoint, xOfs, yOfs = textObj:GetPoint();
	textObj:SetPoint(point, relativeTo, relativePoint, xOfs + 5, yOfs + 2);

	item:SetPoint("TOPLEFT", parent, "TOPLEFT", 10, pos);
	item:SetScript("OnClick", function(item) ClickFunc(item) end);
	item:Show();
	return item;
end


function BBar_CreateOptionsSlider(parent, text, id, x, y, pos, minvalue, maxvalue, step, extraText)

	local Obj = _G["BBarSettingsSlider"..id];
	if( not Obj ) then
		Obj = CreateFrame("Slider", "BBarSettingsSlider"..id, parent, "OptionsSliderTemplate");
	else	Obj:ClearAllPoints();
	end
	Obj:SetWidth(x);
	Obj:SetHeight(y);
	Obj:EnableMouseWheel(true);
	Obj:SetOrientation('HORIZONTAL');
	Obj:SetPoint("TOP", parent, "TOP", -6, pos);
	Obj:SetMinMaxValues(minvalue, maxvalue);
	Obj:SetValue(g_BBarO.SliderValues[id]);
	Obj:SetValueStep(step);
	Obj:SetScript("OnValueChanged", function(self, value) BBar_SliderValChanged(self, value, id); end);
		
	_G[Obj:GetName() .. 'Low']:SetText(tostring(minvalue));
	_G[Obj:GetName() .. 'High']:SetText(tostring(maxvalue));
	local textObj = _G[Obj:GetName().."Text"];
	textObj:SetText(text);
	textObj:SetTextColor(1, 0.8, 0, 1)
	local point, relativeTo, relativePoint, xOfs, yOfs = textObj:GetPoint();
	textObj:SetPoint(point, relativeTo, relativePoint, xOfs, yOfs + 4);

	if(extraText and (extraText > 0)) then
		local TObj = BBar_CreateTextObject("BBarSettingsSlider"..id.."Txt", tostring(g_BBarO.SliderValues[id]), parent, 14, 1, 1, 1, 1, 0, 0, 20, nil);
		TObj:SetPoint("TOPLEFT", Obj, "TOPRIGHT", 10, -4);
	end
	return Obj;
end


function BBar_BuildOptionsFrame()

	local yPos = -16;
	local Obj = BBar_CreateOptionsCheck(g_BBar.OptionsFrame, "Lock Bar Location", 1, yPos, BBar_ToggleMoving);
	yPos = yPos - Obj:GetHeight();
	Obj = BBar_CreateOptionsCheck(g_BBar.OptionsFrame, "Display Button Toolips", 2, yPos, BBar_ToggleHintTT);
	yPos = yPos - Obj:GetHeight();
	Obj = BBar_CreateOptionsCheck(g_BBar.OptionsFrame, "Display Info Toolips", 3, yPos, BBar_ToggleInfoTT);
	yPos = yPos - (Obj:GetHeight() + 10);

	Obj = BBar_CreateOptionsCheck(g_BBar.OptionsFrame, "Minimise on Combat", 4, yPos, BBar_ToggleMinOnC);
	yPos = yPos - Obj:GetHeight();
	Obj = BBar_CreateOptionsCheck(g_BBar.OptionsFrame, "Minimise in Instance", 5, yPos, BBar_ToggleMinOnI);
	yPos = yPos - (Obj:GetHeight() + 10);

	Obj = BBar_CreateOptionsCheck(g_BBar.OptionsFrame, "Swap Reputation Bars Direction", 6, yPos, BBar_ToggleBarDir);
	yPos = yPos - Obj:GetHeight();
	
	yPos = yPos - 32;
	Obj = BBar_CreateOptionsSlider(g_BBar.OptionsFrame, "Reputation Bar Height", 1, 250, 14, yPos, 12, 48, 1, 1);
	yPos = yPos - (Obj:GetHeight() + 22);
	Obj = BBar_CreateOptionsSlider(g_BBar.OptionsFrame, "Reputation Bar Text Alpha", 2, 250, 14, yPos, 0, 1, 0.05, 0);
	yPos = yPos - (Obj:GetHeight() + 42);

	Obj = BBar_CreateOptionsSlider(g_BBar.OptionsFrame, "Profession Bar Height", 3, 250, 14, yPos, 12, 48, 1, 1);
	yPos = yPos - (Obj:GetHeight() + 22);
	Obj = BBar_CreateOptionsSlider(g_BBar.OptionsFrame, "Reputation Bar Text Alpha", 4, 250, 14, yPos, 0, 1, 0.05, 0);

	Obj = CreateFrame("Button", "BBarOptionsResetAll", g_BBar.OptionsFrame, "UIPanelButtonTemplate");
	Obj:SetSize(200, 30);
	Obj:RegisterForClicks("LeftButtonUp");
	Obj:SetPoint("BOTTOM", g_BBar.OptionsFrame, "BOTTOM", 10, 20);
	Obj:SetText("Reset Everything");
	Obj:Show();
	Obj:SetScript("OnEnter", function() GameTooltip:SetOwner(Obj, "ANCHOR_BOTTOMRIGHT");
		GameTooltip:SetText("Except your stored gold information", 1, 1, 1);
		GameTooltip:Show(); end);
	Obj:SetScript("OnLeave", function() GameTooltip:Hide(); end);
	Obj:SetScript("OnClick", BBar_ResetEverything);

end


function BBar_UpdateOptionsFrame()

	_G["BBarSettingsOptionItem1"]:SetChecked(_C((g_BBarO.WindowLock and g_BBarO.WindowLock > 0), true, false));
	_G["BBarSettingsOptionItem2"]:SetChecked(_C((g_BBarO.ShowHintTT and g_BBarO.ShowHintTT > 0), true, false));
	_G["BBarSettingsOptionItem3"]:SetChecked(_C((g_BBarO.ShowInfoTT and g_BBarO.ShowInfoTT > 0), true, false));
	_G["BBarSettingsOptionItem4"]:SetChecked(_C((g_BBarO.MinOnCombat and g_BBarO.MinOnCombat > 0), true, false));
	_G["BBarSettingsOptionItem5"]:SetChecked(_C((g_BBarO.MinOnInst and g_BBarO.MinOnInst > 0), true, false));
	_G["BBarSettingsOptionItem6"]:SetChecked(_C((g_BBarO.BarGrowDir and g_BBarO.BarGrowDir > 0), true, false));
	for i = 1, 4, 1 do	_G["BBarSettingsSlider"..i]:SetValue(g_BBarO.SliderValues[i]);	end
end

function BBar_SaveLoadSettingsOptions(save)

	if(save == 1) then	-- Save
		BBarOptions = "";
		BBarOptions = BBarOptions..tostring(g_BBarO.WindowLock).." ";
		BBarOptions = BBarOptions..tostring(g_BBarO.ShowHintTT).." ";
		BBarOptions = BBarOptions..tostring(g_BBarO.ShowInfoTT).." ";
		BBarOptions = BBarOptions..tostring(g_BBarO.MinOnCombat).." ";
		BBarOptions = BBarOptions..tostring(g_BBarO.MinOnInst).." ";
		BBarOptions = BBarOptions..tostring(g_BBarO.BarGrowDir).." ";
		for i = 1, 4, 1 do	BBarOptions = BBarOptions..tostring(g_BBarO.SliderValues[i]).." ";	end
	else	-- Load
		local optionVals = { strsplit(" ", BBarOptions) };
		if(tonumber(optionVals[1])) then g_BBarO.WindowLock = tonumber(optionVals[1]);		end
		if(tonumber(optionVals[2])) then g_BBarO.ShowHintTT = tonumber(optionVals[2]);		end
		if(tonumber(optionVals[3])) then g_BBarO.ShowInfoTT = tonumber(optionVals[3]);		end
		if(tonumber(optionVals[4])) then g_BBarO.MinOnCombat = tonumber(optionVals[4]);		end
		if(tonumber(optionVals[5])) then g_BBarO.MinOnInst = tonumber(optionVals[5]);		end
		if(tonumber(optionVals[6])) then g_BBarO.BarGrowDir = tonumber(optionVals[6]);		end
		for i = 1, 4, 1 do	if(tonumber(optionVals[i + 6])) then g_BBarO.SliderValues[i] = tonumber(optionVals[i + 6]); end	end
	end
end

